@@ -6,7 +6,7 @@ use warnings;
 use Moo;
 use MooX::Types::MooseLike::Base qw/ ArrayRef HashRef Int Str /;
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 use Data::Dump 'dump';
 use DateTime;
@@ -111,7 +111,7 @@ has [qw/ post_url public_key secret_key /] => (
 has sentry_version => (
     is      => 'ro',
     isa     => Int,
-    default => 3,
+    default => 7,
 );
 
 has timeout => (
@@ -581,6 +581,7 @@ sub _construct_event {
 
         extra       => $self->_merge_hashrefs($self->context()->{extra}, $context{extra}),
         tags        => $self->_merge_hashrefs($self->context()->{tags}, $context{tags}),
+        fingerprint => $context{fingerprint} || $self->context()->{fingerprint} || ['{{ default }}'],
 
         level       => $self->_validate_level($context{level}) || $self->context()->{level} || 'error',
     };
@@ -864,6 +865,10 @@ The hostname on which an event occurred.  Defaults to the system hostname.
 
 Arbitrary key value pairs with tags for categorizing an event.  Defaults to C<{}>.
 
+=item C<< fingerprint => [ 'val1', 'val2', ... } >>
+
+Array of strings used to control how events aggregate in the sentry web interface. The string C<'{{ default }}'> has special meaning when used as the first value; it indicates that sentry should use the default aggregation method in addition to any others specified (useful for fine-grained aggregation). Defaults to C<['{{ default }}']>.
+
 =item C<< timestamp => '1970-01-01T00:00:00' >>
 
 Timestamp of an event.  ISO 8601 format.  Defaults to the current time.  Invalid values may be discarded silently.
